[Scummvm-cvs-logs] scummvm master -> 0ec91de76df9fbe452bc62775d337114179b2fe0

clone2727 clone2727 at gmail.com
Mon Feb 21 23:11:34 CET 2011


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
0ec91de76d SCI: Spell 'canister' correctly


Commit: 0ec91de76df9fbe452bc62775d337114179b2fe0
    https://github.com/scummvm/scummvm/commit/0ec91de76df9fbe452bc62775d337114179b2fe0
Author: Matthew Hoops (clone2727 at gmail.com)
Date: 2011-02-21T14:09:45-08:00

Commit Message:
SCI: Spell 'canister' correctly

Changed paths:
    engines/sci/engine/script_patches.cpp



diff --git a/engines/sci/engine/script_patches.cpp b/engines/sci/engine/script_patches.cpp
index 79a0cfc..f3b6ff8 100644
--- a/engines/sci/engine/script_patches.cpp
+++ b/engines/sci/engine/script_patches.cpp
@@ -355,12 +355,12 @@ const uint16 freddypharkasPatchScoreDisposal[] = {
 };
 
 //  script 235 of freddy pharkas rm235::init and sEnterFrom500::changeState
 //   disable icon 7+8 of iconbar (CD only). When picking up the cannister after
 //   placing it down, the scripts will disable all the other icons. This results
 //   in IconBar::disable doing endless loops even in sierra sci, because there
 //   is no enabled icon left. We remove disabling of icon 8 (which is help),
 //   this fixes the issue.
-const byte freddypharkasSignatureCannisterHang[] = {
+const byte freddypharkasSignatureCanisterHang[] = {
 	12,
 	0x38, 0xf1, 0x00, // pushi f1 (selector disable)
 	0x7a,             // push2
@@ -371,7 +371,7 @@ const byte freddypharkasSignatureCannisterHang[] = {
 	0
 };
 
-const uint16 freddypharkasPatchCannisterHang[] = {
+const uint16 freddypharkasPatchCanisterHang[] = {
 	PATCH_ADDTOOFFSET | +3,
 	0x78,             // push1
 	PATCH_ADDTOOFFSET | +2,
@@ -418,7 +418,7 @@ const uint16 freddypharkasPatchLadderEvent[] = {
 //    script, description,                                      magic DWORD,                                  adjust
 const SciScriptSignature freddypharkasSignatures[] = {
 	{      0, "CD: score early disposal",                    1, PATCH_MAGICDWORD(0x39, 0x0d, 0x43, 0x75),    -3, freddypharkasSignatureScoreDisposal, freddypharkasPatchScoreDisposal },
-	{    235, "CD: cannister pickup hang",                   3, PATCH_MAGICDWORD(0x39, 0x07, 0x39, 0x08),    -4, freddypharkasSignatureCannisterHang, freddypharkasPatchCannisterHang },
+	{    235, "CD: canister pickup hang",                   3, PATCH_MAGICDWORD(0x39, 0x07, 0x39, 0x08),    -4, freddypharkasSignatureCanisterHang, freddypharkasPatchCanisterHang },
 	{    320, "ladder event issue",                          2, PATCH_MAGICDWORD(0x6d, 0x76, 0x38, 0xf5),    -1, freddypharkasSignatureLadderEvent,   freddypharkasPatchLadderEvent },
 	SCI_SIGNATUREENTRY_TERMINATOR
 };
@@ -355,12 +355,12 @@ const uint16 freddypharkasPatchScoreDisposal[] = {
 
 //  script 235 of freddy pharkas rm235::init and sEnterFrom500::changeState
-//   disable icon 7+8 of iconbar (CD only). When picking up the cannister after
+//   disable icon 7+8 of iconbar (CD only). When picking up the canister after
 //   placing it down, the scripts will disable all the other icons. This results
 //   in IconBar::disable doing endless loops even in sierra sci, because there






More information about the Scummvm-git-logs mailing list